==> ZenTaoPMS.max3.0.beta1.php7.1.zip: zentaopms/extension/biz/host/lang/zh-tw.php <==
<?php
$lang->host->common       = '主機';
$lang->host->browse       = '主機列表';
$lang->host->create       = '添加主機';
$lang->host->view         = '主機詳情';
$lang->host->edit         = '編輯';
$lang->host->editAction   = '編輯主機';
$lang->host->delete       = '刪除';
$lang->host->deleteAction = '刪除主機';
$lang->host->treemap      = '主機拓撲圖';
$lang->host->changeStatus = '上架/下架';
$lang->host->byQuery      = '搜索';
$lang->host->reason       = '原因';

$lang->host->name         = '名稱';
$lang->host->type         = '類型';
$lang->host->hardwareType = '硬件類型';
$lang->host->group        = '主機分組';
$lang->host->admin        = '管理賬號';
$lang->host->cabinet      = '機櫃';
$lang->host->privateIP    = '內網IP';
$lang->host->publicIP     = '公網IP';
$lang->host->mac          = 'MAC';
$lang->host->cpuBrand     = 'CPU品牌';
$lang->host->cpuModel     = 'CPU型號';
$lang->host->cpuNumber    = 'CPU數量';
$lang->host->cpuCores     = '單CPU核心數';
$lang->host->cpuRate      = 'CPU頻率';
$lang->host->memory       = '內存大小';
$lang->host->nic          = '網卡速度';
$lang->host->serverRoom   = '機房';

$lang->host->createdBy   = '由誰創建';
$lang->host->createdDate = '創建時間';
$lang->host->editedBy    = '由誰編輯';
$lang->host->editedDate  = '編輯時間';
$lang->host->all         = '所有主機';

$lang->host->groupMaintenance = '分組維護';

$lang->host->status = '狀態';
$lang->host->statusList['online']  = '已上架';
$lang->host->statusList['busy']    = '已超載';
$lang->host->statusList['offline'] = '已下架';

$lang->host->online  = '上架';
$lang->host->busy    = '超載';
$lang->host->offline = '下架';

$lang->host->onlineReason  = '上架原因';
$lang->host->offlineReason = '下架原因';

$lang->host->unitList['GB'] = 'GB';
$lang->host->unitList['TB'] = 'TB';

$lang->host->cpuBrandList[''] = '';
$lang->host->cpuBrandList['intel'] = '英特爾';
$lang->host->cpuBrandList['amd']   = 'AMD';

$lang->host->database = '資料庫';
$lang->host->databaseList['']             = '';
$lang->host->databaseList['mysql55']      = 'MySQL 5.5';
$lang->host->databaseList['mysql56']      = 'MySQL 5.6';
$lang->host->databaseList['mysql57']      = 'MySQL 5.7';
$lang->host->databaseList['mysql80']      = 'MySQL 8.0';
$lang->host->databaseList['oracle10g']    = 'Oracle 10g';
$lang->host->databaseList['oracle11g']    = 'Oracle 11g';
$lang->host->databaseList['mongodb30']    = 'MongoDB 3.0';
$lang->host->databaseList['mongodb34']    = 'MongoDB 3.4';
$lang->host->databaseList['postgresql95'] = 'PostgreSQL 9.5';
$lang->host->databaseList['postgresql96'] = 'PostgreSQL 9.6';

$lang->host->webserver = 'Web Server';
$lang->host->webserverList['']           = '';
$lang->host->webserverList['apache2425'] = 'Apache 2.4.25';
$lang->host->webserverList['apache2426'] = 'Apache 2.4.26';
$lang->host->webserverList['apache2427'] = 'Apache 2.4.27';
$lang->host->webserverList['nginx181']   = 'Nginx 1.8.1';
$lang->host->webserverList['nginx1102']  = 'Nginx 1.10.2';
$lang->host->webserverList['nginx1115']  = 'Nginx 1.11.5';
$lang->host->webserverList['iis6']       = 'IIS 6';
$lang->host->webserverList['iis7']       = 'IIS 7';
$lang->host->webserverList['iis8']       = 'IIS 8';
$lang->host->webserverList['iis10']      = 'IIS 10';

$lang->host->language = '語言環境';
$lang->host->languageList['']   = '';
$lang->host->languageList['php56'] = 'PHP 5.6';
$lang->host->languageList['php70'] = 'PHP 7.0';
$lang->host->languageList['java7'] = 'JAVA 7';
$lang->host->languageList['java8'] = 'JAVA 8';
$lang->host->languageList['c#3']   = 'C# 3.0';
$lang->host->languageList['c#4']   = 'C# 4.0';

$lang->host->treemapList['serverroom'] = '物理拓撲圖';
$lang->host->treemapList['group']      = '分組拓撲圖';

$lang->host->serverModel              = '伺服器型號';
$lang->host->hostType                 = '主機類型';
$lang->host->hostTypeList['physical'] = '實體主機';
$lang->host->hostTypeList['virtual']  = '虛擬主機';

$lang->host->osVersion   = '系統版本';
$lang->host->osName      = '操作系統';
$lang->host->agentPort   = 'agent連接埠';
$lang->host->instanceNum = '最大實列數';
$lang->host->pri         = '優先順序';
$lang->host->tags        = '平台標籤';
$lang->host->provider    = '供應商';
$lang->host->bridgeID    = '虛擬網橋';
$lang->host->osNameList['linux']   = 'Linux';
$lang->host->osNameList['windows'] = 'Microsoft Windows';
$lang->host->osNameList['solaris'] = 'Solaris';
$lang->host->osNameList['netware'] = 'Novell NetWare';
$lang->host->osNameList['esx']     = 'VMware ESX';
$lang->host->osNameList['other']   = 'Other';

$lang->host->tagsList['vm']     = 'VM';
$lang->host->tagsList['native'] = 'Native';
$lang->host->providerList['native'] = 'Native';

$lang->host->linux   = 'Linux';
$lang->host->windows = 'Microsoft Windows';
$lang->host->solaris = 'Solaris';
$lang->host->netware = 'Novell NetWare';
$lang->host->esx     = 'VMware ESX';
$lang->host->other   = 'Other';

$lang->host->linuxList['']   = '';
$lang->host->linuxList['centos65'] = 'CentOS 6.5';
$lang->host->linuxList['centos66'] = 'CentOS 6.6';
$lang->host->linuxList['centos67'] = 'CentOS 6.7';
$lang->host->linuxList['centos70'] = 'CentOS 7.0';
$lang->host->linuxList['centos71'] = 'CentOS 7.1';

$lang->host->windowsList[''] = '';
$lang->host->windowsList['win10-pro']      = 'Windows 10 pro';
$lang->host->windowsList['winserver08x64'] = 'Windows Server2008 x64';
$lang->host->windowsList['winserver12']    = 'Windows Server2012';
$lang->host->windowsList['winserver16']    = 'Windows Server2016';

$lang->host->solarisList[''] = '';
$lang->host->solarisList['solaris10']    = 'Solaris 10';
$lang->host->solarisList['solaris10x64'] = 'Solaris 10 x64';
$lang->host->solarisList['solaris11']    = 'Solaris 11';

$lang->host->netwareList[''] = '';
$lang->host->netwareList['netware5'] = 'NetWare 5';
$lang->host->netwareList['netware6'] = 'NetWare 6';

$lang->host->esxList[''] = '';
$lang->host->esxList['esx']  = 'VMware ESX/ESXi 4';
$lang->host->esxList['esx5'] = 'VMware ESXi 5';
$lang->host->esxList['esx6'] = 'VMware ESXi 6';

$lang->host->otherList['']   = '';
$lang->host->otherList['freebsd']   = 'FreeBSD';
$lang->host->otherList['freebsdx64']   = 'FreeBSD X64';

$lang->host->diskSize   = '硬碟容量';
$lang->host->diskType   = '硬碟類型';
$lang->host->diskTypeList['hdd'] = '機械硬碟';
$lang->host->diskTypeList['ssd'] = '固態硬碟';

$lang->host->confirmDelete  = '是否刪除該主機記錄？';

$lang->host->notice = new stdclass();
$lang->host->notice->memory    = '內存大小只能為數字！';
$lang->host->notice->diskSize  = '硬碟容量只能為數字！';
$lang->host->notice->cpuNumber = 'CPU數量只能為數字！';
$lang->host->notice->cpuCores  = 'CPU核心數只能為數字！';

==> ZenTaoPMS.max4.4.beta1.php7.1.zip: zentaopms/extension/biz/host/lang/zh-tw.php <==
<?php
$lang->host->common       = '主機';
$lang->host->browse       = '主機列表';
$lang->host->create       = '添加主機';
$lang->host->view         = '主機詳情';
$lang->host->edit         = '編輯';
$lang->host->editAction   = '編輯主機';
$lang->host->delete       = '刪除';
$lang->host->deleteAction = '刪除主機';
$lang->host->treemap      = '主機拓撲圖';
$lang->host->changeStatus = '上架/下架';
$lang->host->byQuery      = '搜索';
$lang->host->reason       = '原因';

$lang->host->name         = '名稱';
$lang->host->type         = '類型';
$lang->host->hardwareType = '硬件類型';
$lang->host->group        = '主機分組';
$lang->host->admin        = '管理賬號';
$lang->host->cabinet      = '機櫃';
$lang->host->intranet     = '內網IP';
$lang->host->extranet     = '外網IP';
$lang->host->mac          = 'MAC';
$lang->host->cpuBrand     = 'CPU品牌';
$lang->host->cpuModel     = 'CPU型號';
$lang->host->cpuNumber    = 'CPU數量';
$lang->host->cpuCores     = '單CPU核心數';
$lang->host->cpuRate      = 'CPU頻率';
$lang->host->memory       = '內存大小';
$lang->host->serverRoom   = '機房';

$lang->host->createdBy   = '由誰創建';
$lang->host->createdDate = '創建時間';
$lang->host->editedBy    = '由誰編輯';
$lang->host->editedDate  = '編輯時間';
$lang->host->all         = '全部主機';

$lang->host->empty = '暫時沒有主機';

$lang->host->groupMaintenance = '分組維護';

$lang->host->status = '狀態';
$lang->host->statusList['online']  = '已上架';
$lang->host->statusList['busy']    = '已超載';
$lang->host->statusList['offline'] = '已下架';

$lang->host->online  = '上架';
$lang->host->busy    = '超載';
$lang->host->offline = '下架';

$lang->host->onlineReason  = '上架原因';
$lang->host->offlineReason = '下架原因';

$lang->host->unitList['GB'] = 'GB';
$lang->host->unitList['TB'] = 'TB';

$lang->host->cpuBrandList[''] = '';
$lang->host->cpuBrandList['intel'] = '英特爾';
$lang->host->cpuBrandList['amd']   = 'AMD';

$lang->host->database = '資料庫';
$lang->host->databaseList['']             = '';
$lang->host->databaseList['mysql55']      = 'MySQL 5.5';
$lang->host->databaseList['mysql56']      = 'MySQL 5.6';
$lang->host->databaseList['mysql57']      = 'MySQL 5.7';
$lang->host->databaseList['mysql80']      = 'MySQL 8.0';
$lang->host->databaseList['oracle10g']    = 'Oracle 10g';
$lang->host->databaseList['oracle11g']    = 'Oracle 11g';
$lang->host->databaseList['mongodb30']    = 'MongoDB 3.0';
$lang->host->databaseList['mongodb34']    = 'MongoDB 3.4';
$lang->host->databaseList['postgresql95'] = 'PostgreSQL 9.5';
$lang->host->databaseList['postgresql96'] = 'PostgreSQL 9.6';

$lang->host->webserver = 'Web Server';
$lang->host->webserverList['']           = '';
$lang->host->webserverList['apache2425'] = 'Apache 2.4.25';
$lang->host->webserverList['apache2426'] = 'Apache 2.4.26';
$lang->host->webserverList['apache2427'] = 'Apache 2.4.27';
$lang->host->webserverList['nginx181']   = 'Nginx 1.8.1';
$lang->host->webserverList['nginx1102']  = 'Nginx 1.10.2';
$lang->host->webserverList['nginx1115']  = 'Nginx 1.11.5';
$lang->host->webserverList['iis6']       = 'IIS 6';
$lang->host->webserverList['iis7']       = 'IIS 7';
$lang->host->webserverList['iis8']       = 'IIS 8';
$lang->host->webserverList['iis10']      = 'IIS 10';

$lang->host->language = '語言環境';
$lang->host->languageList['']   = '';
$lang->host->languageList['php56'] = 'PHP 5.6';
$lang->host->languageList['php70'] = 'PHP 7.0';
$lang->host->languageList['java7'] = 'JAVA 7';
$lang->host->languageList['java8'] = 'JAVA 8';
$lang->host->languageList['c#3']   = 'C# 3.0';
$lang->host->languageList['c#4']   = 'C# 4.0';

$lang->host->featureBar['browse']['all']        = $lang->host->all;
$lang->host->featureBar['browse']['serverroom'] = '物理拓撲圖';
$lang->host->featureBar['browse']['group']      = '分組拓撲圖';

$lang->host->serverModel              = '伺服器型號';
$lang->host->hostType                 = '主機類型';
$lang->host->hostTypeList['physical'] = '實體主機';
$lang->host->hostTypeList['virtual']  = '虛擬主機';

$lang->host->osVersion   = '系統版本';
$lang->host->osName      = '操作系統';
$lang->host->zap         = 'agent連接埠';
$lang->host->instanceNum = '最大實列數';
$lang->host->pri         = '優先順序';
$lang->host->tags        = '平台標籤';
$lang->host->provider    = '供應商';
$lang->host->bridgeID    = '虛擬網橋';

$lang->host->osNameList['linux']   = 'Linux';
$lang->host->osNameList['windows'] = 'Microsoft Windows';
$lang->host->osNameList['solaris'] = 'Solaris';
$lang->host->osNameList['netware'] = 'Novell NetWare';
$lang->host->osNameList['esx']     = 'VMware ESX';
$lang->host->osNameList['other']   = 'Other';

$lang->host->tagsList['vm']     = 'VM';
$lang->host->tagsList['native'] = 'Native';
$lang->host->providerList['native'] = 'Native';

$lang->host->linux   = 'Linux';
$lang->host->windows = 'Microsoft Windows';
$lang->host->solaris = 'Solaris';
$lang->host->netware = 'Novell NetWare';
$lang->host->esx     = 'VMware ESX';
$lang->host->other   = 'Other';

$lang->host->linuxList['']   = '';
$lang->host->linuxList['centos65'] = 'CentOS 6.5';
$lang->host->linuxList['centos66'] = 'CentOS 6.6';
$lang->host->linuxList['centos67'] = 'CentOS 6.7';
$lang->host->linuxList['centos70'] = 'CentOS 7.0';
$lang->host->linuxList['centos71'] = 'CentOS 7.1';

$lang->host->windowsList[''] = '';
$lang->host->windowsList['win10-pro']      = 'Windows 10 pro';
$lang->host->windowsList['winserver08x64'] = 'Windows Server2008 x64';
$lang->host->windowsList['winserver12']    = 'Windows Server2012';
$lang->host->windowsList['winserver16']    = 'Windows Server2016';

$lang->host->solarisList[''] = '';
$lang->host->solarisList['solaris10']    = 'Solaris 10';
$lang->host->solarisList['solaris10x64'] = 'Solaris 10 x64';
$lang->host->solarisList['solaris11']    = 'Solaris 11';

$lang->host->netwareList[''] = '';
$lang->host->netwareList['netware5'] = 'NetWare 5';
$lang->host->netwareList['netware6'] = 'NetWare 6';

$lang->host->esxList[''] = '';
$lang->host->esxList['esx']  = 'VMware ESX/ESXi 4';
$lang->host->esxList['esx5'] = 'VMware ESXi 5';
$lang->host->esxList['esx6'] = 'VMware ESXi 6';

$lang->host->otherList['']   = '';
$lang->host->otherList['freebsd']   = 'FreeBSD';
$lang->host->otherList['freebsdx64']   = 'FreeBSD X64';

$lang->host->diskSize   = '硬碟容量';
$lang->host->diskType   = '硬碟類型';
$lang->host->diskTypeList['hdd'] = '機械硬碟';
$lang->host->diskTypeList['ssd'] = '固態硬碟';

$lang->host->confirmDelete  = '是否刪除該主機記錄？';

$lang->host->notice = new stdclass();
$lang->host->notice->memory    = '內存大小只能為數字！';
$lang->host->notice->diskSize  = '硬碟容量只能為數字！';
$lang->host->notice->cpuNumber = 'CPU數量只能為數字！';
$lang->host->notice->cpuCores  = 'CPU核心數只能為數字！';
$lang->host->notice->int       = '『%s』應當是正整數！';
$lang->host->notice->ip        = '『%s』格式不正確！';
